@@ -1,3 +1,4 @@
+#Store color codes
 colors = {
   "standard"   :  "\033[0m",
   "black"   :  "\033[30m",
@@ -10,5 +11,5 @@ colors = {
   "white"   :  "\033[37m"
 }
 
-def print_colored(text, color):
+def clrprint(text, color):
   print(colors[color] + text + colors["standard"])
\ No newline at end of file
